package run;


import cn.tign.hz.comm.DeclareDetails;
import cn.tign.hz.factory.Factory;
import cn.tign.hz.factory.base.OrgIdentityVerify;
import cn.tign.hz.factory.orgIdentity.*;
import cn.tign.hz.factory.response.orgIdentity.OrgFourFactorsResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * 企业认证服务纯API版
 * @version JDK1.8
 * @date 2024/5/11
 */
public class OrgApiVerifyDemo {
    static {
        DeclareDetails.showImportantMessage();//demo声明明细
//        正式环境域名：https://openapi.esign.cn
//        模拟环境（沙箱环境）域名：https://smlopenapi.esign.cn
        String host = "https://smlopenapi.esign.cn"; //网关
        String project_id = "74XXXX";//应用id
        String project_scert = "0c525***7e88e4";//应用secret
        Factory.init(host, project_id, project_scert);//初始化，传入请求网关和应用id以及密钥,全局运行一次
        Factory.setDebug(true);//开启日志，测试阶段建议开启，方便记录数据，日志保存在根目录的log.txt文件中
    }

    public static void main(String[] args) {
        Logger logger = LoggerFactory.getLogger(OrgApiVerifyDemo.class);
        try {
            String name = "企业名字";//机构名称
            String orgCode = "XXXXXX";//机构证件号
            String legalRepName = "XXXXXX";//法人姓名
            String legalRepIdNo = "";//法人身份证号
            String mobileNo = "";//法人手机号

            /**
             * 【4要素】或【3要素】企业核身认证 二选一接入
             * 这里以【4要素】例
             * 文档地址：https://open.esign.cn/doc/opendoc/identity_service/ikp0qg
             */

            logger.info("-----------------【4要素】企业核身认证 start-----------------");
            OrgFourFactors orgFourFactors = OrgIdentityVerify.orgFourFactors(name, orgCode, legalRepName, legalRepIdNo);
            OrgFourFactorsResponse orgFourFactorsResponse = orgFourFactors.execute();
            String flowId = orgFourFactorsResponse.getData().getFlowId();
            logger.info("-----------------【4要素】企业核身认证 end-----------------");

//            logger.info("-----------------【3要素】企业核身认证 start-----------------");
//            OrgThreeFactors orgThreeFactors = OrgIdentityVerify.orgThreeFactors(name, orgCode, legalRepName);
//            orgThreeFactors.execute();
//            logger.info("-----------------【3要素】企业核身认证 end-----------------");

            /**
             * 法人本人认证、法人授权签署认证、发起随机金额打款认证、反向打款认证 四个方式选择其中一种认证方式即可
             * 这里以法人授权签署认证为例
             * 文档地址：https://open.esign.cn/doc/opendoc/identity_service/dyyohd
             */

            logger.info("-----------------【授权书认证】发起授权书签署 start-----------------");
            OrglegalRepSignAuth orglegalRepSignAuth = OrgIdentityVerify.orglegalRepSignAuth(flowId, mobileNo);
            orglegalRepSignAuth.setLegalRepIdNo(legalRepIdNo);
            orglegalRepSignAuth.execute();
            logger.info("-----------------【授权书认证】发起授权书签署 end-----------------");


        } catch (Exception e) {
            e.printStackTrace();
        }
        System.out.println("运行结束");
    }
}
