package run;

import cn.tign.hz.comm.DeclareDetails;
import cn.tign.hz.exception.DefineException;
import cn.tign.hz.factory.Factory;
import cn.tign.hz.factory.base.PsnIdentityVerify;
import cn.tign.hz.factory.indivIdentity.*;
import cn.tign.hz.factory.response.indivIdentity.*;
import cn.tign.hz.factory.response.infoverify.Telecom3FactorsResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * 个人认证服务纯API版
 * @version JDK1.8
 * @date 2024/5/11
 */

public class PsnApiVerifyDemo {
    static {
        DeclareDetails.showImportantMessage();//demo声明明细
//        正式环境域名：https://openapi.esign.cn
//        模拟环境（沙箱环境）域名：https://smlopenapi.esign.cn
        String host = "https://smlopenapi.esign.cn"; //网关
        String project_id = "74XXXX";//应用id
        String project_scert = "0c525***7e88e4";//应用secret
        Factory.init(host, project_id, project_scert);//初始化，传入请求网关和应用id以及密钥,全局运行一次
        Factory.setDebug(true);//开启日志，测试阶段建议开启，方便记录数据，日志保存在根目录的log.txt文件中


    }

    public static void main(String[] args) throws DefineException {
        Logger logger = LoggerFactory.getLogger(PsnApiVerifyDemo.class);
        try {

            //请求参数：
            String name = "姓名";//个人姓名
            String idNo = "XXXXXXX";//个人证件号
            String callbackUrl = "https://open.esign.cn"; //认证完成以后前端需要跳转的页面地址
            String mobileNo = "";//手机号
            String bankCardNo = "";//银行卡号

            /**
             * 以上只是案例参数，其他参数请看对接文档按需传入
             * 以下三种认证任选一种完成认证即可
             * 接口流程参考对接指南：https://open.esign.cn/doc/opendoc/identity_service/shiming#BBe6M
             */

            switch (0) {
                case 0:
                    logger.info("-----------------【人脸识别认证】个人核身 start-----------------");
                    FaceIdentity faceIdentity = PsnIdentityVerify.faceIdentity(name, idNo, "TENCENT", callbackUrl);
                    FaceIdentityResponse faceIdentityResponse = faceIdentity.execute();
                    String flowId0 = faceIdentityResponse.getData().getFlowId();
                    logger.info("-----------------【人脸识别认证】个人核身 end-----------------");


                    logger.info("-----------------查询个人刷脸状态 start-----------------");
                    QryFaceStatus qryFaceStatus = PsnIdentityVerify.qryFaceStatus(flowId0);
                    qryFaceStatus.execute();
                    logger.info("-----------------查询个人刷脸状态 end-----------------");

                    break;
                case 1:
                    logger.info("-----------------【手机号认证】运营商3要素核身 start-----------------");
                    IndividualTelecom3Factors telecom3Factors = PsnIdentityVerify.individualTelecom3Factors(name, idNo, mobileNo);
                    IndividualTelecom3FactorsResponse telecom3FactorsResponse = telecom3Factors.execute();
                    String flowId1 = telecom3FactorsResponse.getData().getFlowId();
                    logger.info("-----------------【手机号认证】运营商3要素核身 end-----------------");


                    logger.info("-----------------【手机号认证】短信验证码校验 start-----------------");
                    String authCode = "";//发起运营商三要素以后收到的短信验证码
                    Tel3FactorsCodeVerify tel3FactorsCodeVerify = PsnIdentityVerify.tel3FactorsCodeVerify(flowId1, authCode);
                    tel3FactorsCodeVerify.execute();
                    logger.info("-----------------【手机号认证】短信验证码校验 end-----------------");
                    break;
                case 2:
                    logger.info("-----------------【银行卡认证】银行卡4要素核身 start-----------------");
                    IndividualBankCard4Factors bankCard4Factors = PsnIdentityVerify.individualBankCard4Factors(name, "INDIVIDUAL_CH_IDCARD", idNo, mobileNo, bankCardNo);
                    IndividualBankCard4FactorsResponse bankCard4FactorsResponse =  bankCard4Factors.execute();
                    String flowId2 = bankCard4FactorsResponse.getData().getFlowId();
                    logger.info("-----------------【银行卡认证】银行卡4要素核身 end-----------------");


                    logger.info("-----------------【银行卡认证】预留手机号校验 start-----------------");
                    authCode = "";//发起银行卡四要素以后手机收到的短信验证码
                    PsnIdentityVerify.bankCard4FactorsCodeVerify(flowId2, authCode);
                    logger.info("-----------------【银行卡认证】预留手机号校验 end-----------------");
                    break;
                default:
                    logger.info("====>请选择应用场景<=====");
                    break;

            }


        } catch (Exception e) {
            e.printStackTrace();
        }
        System.out.println("运行结束");
    }

}
